import sqs = require('@aws-cdk/aws-sqs');
import sfn = require('@aws-cdk/aws-stepfunctions');
import { Duration } from '@aws-cdk/core';
/**
 * Properties for SendMessageTask
 */
export interface SendToQueueProps {
    /**
     * The text message to send to the queue.
     */
    readonly messageBody: sfn.TaskInput;
    /**
     * The length of time, in seconds, for which to delay a specific message.
     *
     * Valid values are 0-900 seconds.
     *
     * @default Default value of the queue is used
     */
    readonly delay?: Duration;
    /**
     * The token used for deduplication of sent messages.
     *
     * @default Use content-based deduplication
     */
    readonly messageDeduplicationId?: string;
    /**
     * The tag that specifies that a message belongs to a specific message group.
     *
     * Required for FIFO queues. FIFO ordering applies to messages in the same message
     * group.
     *
     * @default No group ID
     */
    readonly messageGroupId?: string;
    /**
     * Whether to pause the workflow until a task token is returned
     *
     * @default false
     */
    readonly waitForTaskToken?: boolean;
}
/**
 * A StepFunctions Task to invoke a Lambda function.
 *
 * A Function can be used directly as a Resource, but this class mirrors
 * integration with other AWS services via a specific class instance.
 */
export declare class SendToQueue implements sfn.IStepFunctionsTask {
    private readonly queue;
    private readonly props;
    private readonly waitForTaskToken;
    constructor(queue: sqs.IQueue, props: SendToQueueProps);
    bind(_task: sfn.Task): sfn.StepFunctionsTaskConfig;
}
